@@ -5,6 +5,7 @@ use futures::stream::StreamExt;
 use hyper::{service, Body as HyperBody, Request, Response, Server};
 use std::{convert::Infallible, net::SocketAddr, path::PathBuf, sync::Arc};
 use tokio::sync::Mutex;
+use tracing_subscriber::filter::EnvFilter;
 use viceroy_lib::{
     body::Body,
     config::{Backend, Backends},
@@ -113,6 +114,20 @@ impl Test {
     pub async fn against(&self, req: Request<impl Into<HyperBody>>) -> Response<Body> {
         let _test_lock_guard = TEST_LOCK.lock().await;
 
+        // Install a tracing subscriber. We use a human-readable event formatter in tests, using a
+        // writer that supports input capturing for `cargo test`. This subscribes to all events in
+        // the `viceroy-lib` library.
+        tracing_subscriber::fmt()
+            .with_env_filter(
+                EnvFilter::from_default_env().add_directive("viceroy_lib=trace".parse().unwrap()),
+            )
+            .pretty()
+            .with_test_writer()
+            // `try_init` returns an `Err` if the initialization was unsuccessful, likely because a
+            // global subscriber was already installed. we will ignore this error if it happens.
+            .try_init()
+            .ok();
+
         let mut module_path = PathBuf::from(FIXTURE_PATH);
         module_path.push(&self.fixture);
 
